===============
django-page-cms
===============

This Django CMS enable you to create and administrate hierarchical pages in a simple and powerful way.

Django page CMS is based around a placeholders concept. A placeholder is special template tag that
you use in your page templates. Every time you add a placeholder in your template  a field
dynamically appears in the page admin.

.. image:: http://github.com/batiste/django-page-cms/raw/master/doc/admin-screenshot1.png

Documentation
=============

For more informations about the product:

http://packages.python.org/django-page-cms/

